@@ -34,8 +34,8 @@ GPL.
 // enigmailCommon.js: shared JS functions for Enigmail
 
 // This Enigmail version and compatible Enigmime version
-var gEnigmailVersion = "0.92.1.0";
-var gEnigmimeVersion = "0.92.1.0";
+var gEnigmailVersion = "0.93.2.0";
+var gEnigmimeVersion = "0.93.2.0";
 
 // Maximum size of message directly processed by Enigmail
 const ENIG_MSG_BUFFER_SIZE = 96000;
@@ -62,6 +62,7 @@ const ENIG_CLIPBOARD_HELPER_CONTRACTID = "@mozilla.org/widget/clipboardhelper;1"
 const ENIG_TRANSFERABLE_CONTRACTID = "@mozilla.org/widget/transferable;1"
 const ENIG_LOCALE_SVC_CONTRACTID = "@mozilla.org/intl/nslocaleservice;1";
 const ENIG_DATE_FORMAT_CONTRACTID = "@mozilla.org/intl/scriptabledateformat;1"
+const ENIG_ACCOUNT_MANAGER_CONTRACTID = "@mozilla.org/messenger/account-manager;1";
 
 const ENIG_LOCALFILEOUTPUTSTREAM_CONTRACTID =
                               "@mozilla.org/network/file-output-stream;1";
@@ -78,6 +79,10 @@ const ENIG_IOSERVICE_CONTRACTID = "@mozilla.org/network/io-service;1";
 const ENIGMAIL_PREFS_ROOT       = "extensions.enigmail.";
 const ENIG_C = Components;
 
+// Key algorithms
+const ENIG_KEYTYPE_DSA = 1;
+const ENIG_KEYTYPE_RSA = 2;
+
 // Interfaces
 const nsIEnigmail               = ENIG_C.interfaces.nsIEnigmail;
 const nsIEnigStrBundle          = ENIG_C.interfaces.nsIStringBundleService;
@@ -253,7 +258,7 @@ function GetEnigmailSvc() {
 }
 
 
-function EnigUpdate_0_80() {
+function EnigUpdatePre0_8() {
   try {
     var oldVer=EnigGetPref("configuredVersion");
 
@@ -261,7 +266,8 @@ function EnigUpdate_0_80() {
       if ((oldVer.substring(0,4)<"0.89") && (navigator.vendor=="Thunderbird")) {
         // uninstall globally installed enigmime on Thunderbird
         var ioService = enigGetService("@mozilla.org/network/io-service;1", "nsIIOService");
-        var sysCompDir = this.gDirService.get("ComsD", ENIG_C.interfaces.nsIFile);
+        var dirService = enigGetService("@mozilla.org/file/directory_service;1", "nsIProperties");
+        var sysCompDir = dirService.get("ComsD", ENIG_C.interfaces.nsIFile);
         
         for (var f in [ "enigmime.xpt", "libenigmime.so", "enigmail.dll", "libenigmime.dylib" ]) {
           var compFile = sysCompDir.clone();
@@ -284,8 +290,7 @@ function EnigUpdate_0_80() {
         }
       }
       if (oldVer.substring(0,4)<"0.81") {
-        window.open("chrome://enigmail/content/enigmailUpgrade.xul",
-            "", "chrome,modal,centerscreen");
+        EnigOpenSetupWizard();
       }
     }
   }
@@ -295,52 +300,15 @@ function EnigUpdate_0_80() {
 function EnigConfigure() {
   try {
     // Updates for specific versions (to be cleaned-up periodically)
-    EnigUpdate_0_80();
+    EnigUpdatePre0_8();
   } catch (ex) {}
 
-  var msg = EnigGetString("configNow",gEnigmailVersion);
-
-  var checkValueObj = new Object();
-  checkValueObj.value = false;
-
-  var buttonPressed = gEnigPromptSvc.confirmEx(window,
-                                           EnigGetString("configEnigmail"),
-                                            msg,
-                                            ENIG_THREE_BUTTON_STRINGS,
-                                            EnigGetString("dlgYes"),
-                                            EnigGetString("dlgNo"),
-                                            EnigGetString("dlgNever"),
-                                            "",
-                                            checkValueObj);
-
-  DEBUG_LOG("enigmailCommon.js: EnigConfigure: "+buttonPressed+" \n");
-
-  if (buttonPressed == 1)  // Configure later
-    return;
-
-  var obj = new Object;
-  var prefList = gPrefEnigmail.getChildList("",obj);
-
-  for (var prefItem in prefList) {
-    var prefName=prefList[prefItem];
-    if (prefName.search(/AlertCount$/) >= 0) {
-       // Reset alert count to default value
-      try {
-        gPrefEnigmail.clearUserPref(prefName);
-      } catch(ex) {
-      }
-    }
-  }
-
-  if (buttonPressed == 0) {
-    // Configure now
-    EnigPrefWindow(true,(navigator.vendor=="Thunderbird" ? "thunderbird" : "seamonkey"));
-                             
-  } else {
-    // "Do not ask me again" => "already configured"
-    EnigSetPref("configuredVersion", gEnigmailVersion);
-    EnigSavePrefs();
+  var oldVer=EnigGetPref("configuredVersion");
+  if (oldVer == "") {
+    EnigOpenSetupWizard();
   }
+  EnigSetPref("configuredVersion", gEnigmailVersion);
+  EnigSavePrefs();
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -857,8 +825,10 @@ EnigRequestObserver.prototype = {
 function EnigConvertFromUnicode(text, charset) {
   DEBUG_LOG("enigmailCommon.js: EnigConvertFromUnicode: "+charset+"\n");
 
-  if (!text || !charset /*|| (charset.toLowerCase() == "iso-8859-1")*/)
-    return text;
+  if (!text)
+    return "";
+
+  if (! charset) charset="utf-8";
 
   // Encode plaintext
   try {
@@ -1523,6 +1493,9 @@ function EnigLoadKeyList(refresh, keyListObj) {
         keyObj.fpr=listRow[USER_ID];
         break;
       case "uid":
+        if (listRow[USER_ID].length == 0) {
+          listRow[USER_ID] = "-";
+        }
         if (typeof(keyObj.userId) != "string") {
           keyObj.userId=EnigConvertGpgToUnicode(listRow[USER_ID].replace(/\\e3A/g, ":"));
           keyListObj.keySortList.push({userId: keyObj.userId, keyId: keyObj.keyId});
@@ -1732,3 +1705,8 @@ function enigGetService (aURL, aInterface)
   
   return null;
 }
+
+function EnigOpenSetupWizard() {
+  window.open("chrome://enigmail/content/enigmailSetupWizard.xul",
+            "", "chrome,modal,centerscreen");
+}
