@@ -390,10 +390,17 @@ function enigExtractAndAttachKey(uid) {
 
   // add attachment to msg
   AddAttachment(keyAttachment);
-  var attachmentBox = document.getElementById("attachments-box");
-  attachmentBox.hidden = false;
-  document.getElementById("attachmentbucket-sizer").hidden=false;
-
+  
+  if (typeof(ChangeAttachmentBucketVisibility) == "function") {
+    // TB 1.1
+    ChangeAttachmentBucketVisibility(false);
+  }
+  else {
+    // TB 1.0
+    var attachmentBox = document.getElementById("attachments-box");
+    attachmentBox.hidden = false;
+    document.getElementById("attachmentbucket-sizer").hidden=false;
+  }
   gContentChanged = true;
 }
 
@@ -671,14 +678,21 @@ function enigEncryptMsg(msgSendType) {
   var gotSendFlags = gEnigSendMode;
   var sendFlags=0;
   window.enigmailSendFlags=0;
+  
+  var autoSaveAsDraft = nsIMsgCompDeliverMode.SaveAsDraft;
+  try {
+    // TB 1.5 only
+    autoSaveAsDraft = nsIMsgCompDeliverMode.AutoSaveAsDraft;
+  }
+  catch (ex) {}
+  
   switch (msgSendType) {
   case nsIMsgCompDeliverMode.Later:          
     sendFlags |= nsIEnigmail.SEND_LATER;
     break;
   case nsIMsgCompDeliverMode.SaveAsDraft:   
-    sendFlags |=  nsIEnigmail.SAVE_MESSAGE;
-    break;
-  case nsIMsgCompDeliverMode.SaveAsTemplate: 
+  case nsIMsgCompDeliverMode.SaveAsTemplate:
+  case autoSaveAsDraft:
     sendFlags |= nsIEnigmail.SAVE_MESSAGE;
     break;
   }
@@ -771,7 +785,7 @@ function enigEncryptMsg(msgSendType) {
        optSendFlags |= nsIEnigmail.SEND_ALWAYS_TRUST;
      }
 
-     if (EnigGetPref("encryptToSelf")) {
+     if (EnigGetPref("encryptToSelf") || (sendFlags & nsIEnigmail.SAVE_MESSAGE)) {
        optSendFlags |= nsIEnigmail.SEND_ENCRYPT_TO_SELF;
      }
 
@@ -809,58 +823,68 @@ function enigEncryptMsg(msgSendType) {
      DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg:gMsgCompose="+gMsgCompose+"\n");
 
      var toAddrList = [];
-     if (msgCompFields.to) {
-       var recList = msgCompFields.SplitRecipients(msgCompFields.to, true)
-       enigAddRecipients(toAddrList, recList);
+     if (sendFlags & nsIEnigmail.SAVE_MESSAGE) {
+        if (userIdValue.search(/@/) == -1) {
+          toAddrList.push(userIdValue);
+        }
+        else {
+          enigAddRecipients(toAddrList, [ userIdValue ]);
+        }
      }
+     else {
+       if (msgCompFields.to) {
+         var recList = msgCompFields.SplitRecipients(msgCompFields.to, true)
+         enigAddRecipients(toAddrList, recList);
+       }
 
-     if (msgCompFields.cc) {
-       recList = msgCompFields.SplitRecipients(msgCompFields.cc, true)
-       enigAddRecipients(toAddrList, recList);
-     }
+       if (msgCompFields.cc) {
+         recList = msgCompFields.SplitRecipients(msgCompFields.cc, true)
+         enigAddRecipients(toAddrList, recList);
+       }
 
-     if (msgCompFields.bcc) {
-       recList = msgCompFields.SplitRecipients(msgCompFields.bcc, true)
-       enigAddRecipients(toAddrList, recList);
+       if (msgCompFields.bcc) {
+         recList = msgCompFields.SplitRecipients(msgCompFields.bcc, true)
+         enigAddRecipients(toAddrList, recList);
 
-       var bccLC = EnigStripEmail(msgCompFields.bcc).toLowerCase()
-       DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: BCC: "+bccLC+"\n");
+         var bccLC = EnigStripEmail(msgCompFields.bcc).toLowerCase()
+         DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: BCC: "+bccLC+"\n");
 
-       var selfBCC = gEnigIdentity.email && (gEnigIdentity.email.toLowerCase() == bccLC);
+         var selfBCC = gEnigIdentity.email && (gEnigIdentity.email.toLowerCase() == bccLC);
 
-       if (selfBCC) {
-         DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: Self BCC\n");
+         if (selfBCC) {
+           DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: Self BCC\n");
 
-       } else if (sendFlags & ENIG_ENCRYPT) {
-         // BCC and encryption
+         } else if (sendFlags & ENIG_ENCRYPT) {
+           // BCC and encryption
 
-         if (encryptIfPossible) {
-           sendFlags &= ~ENIG_ENCRYPT;
-           DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: No default encryption because of BCC\n");
+           if (encryptIfPossible) {
+             sendFlags &= ~ENIG_ENCRYPT;
+             DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: No default encryption because of BCC\n");
 
-         } else {
-           if (!EnigConfirm(EnigGetString("sendingBCC"))) {
-             window.cancelSendMessage=true;
-             return;
+           } else {
+             if (!EnigConfirm(EnigGetString("sendingBCC"))) {
+               window.cancelSendMessage=true;
+               return;
+             }
            }
          }
        }
-     }
 
-     if (newsgroups) {
-       toAddrList.push(newsgroups);
+       if (newsgroups) {
+         toAddrList.push(newsgroups);
 
-       if (sendFlags & ENIG_ENCRYPT) {
+         if (sendFlags & ENIG_ENCRYPT) {
+
+           if (!encryptIfPossible) {
+             EnigAlert(EnigGetString("sendingNews"));
+             window.cancelSendMessage=true;
+             return;
+           }
+
+           sendFlags &= ~ENIG_ENCRYPT;
+           DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: No default encryption because of newsgroups\n");
 
-         if (!encryptIfPossible) {
-           EnigAlert(EnigGetString("sendingNews"));
-           window.cancelSendMessage=true;
-           return;
          }
-
-         sendFlags &= ~ENIG_ENCRYPT;
-         DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: No default encryption because of newsgroups\n");
-
        }
      }
 
@@ -1484,11 +1508,20 @@ function enigGenericSendMessage( msgType )
         {
           if (gEnigPromptSvc)
           {
+            var msgTitle;
+            try {
+              // TB 1.1
+              msgTitle = sComposeMsgsBundle.getString("sendMsgTitle");
+            }
+            catch (ex) {
+              // TB <= 1.0
+              msgTitle = sComposeMsgsBundle.getString("subjectDlogTitle");
+            }
             var result = {value:sComposeMsgsBundle.getString("defaultSubject")};
             if (gEnigPromptSvc.prompt(
-              window,
-              sComposeMsgsBundle.getString("subjectDlogTitle"),
-              sComposeMsgsBundle.getString("subjectDlogMessage"),
+                        window,
+                        msgTitle,
+                        sComposeMsgsBundle.getString("subjectDlogMessage"),
                         result,
               null,
               {value:0}
@@ -1789,16 +1822,15 @@ function enigDecryptQuote(interactive) {
 
   var docText = EnigEditorGetContentsAs("text/plain", encoderFlags);
 
-  if (docText.indexOf("-----BEGIN PGP ") < 0)
+  var blockBegin = docText.indexOf("-----BEGIN PGP ");
+  if (blockBegin < 0)
     return;
 
   // Determine indentation string
-  var matches = docText.match(/(^|\n)([ \t]*>*[ \t]*)-----BEGIN PGP /);
-
-  var indentStr= "";
-  if (matches && (matches.length > 2)) {
-    indentStr = matches[2];
-  }
+  var indentBegin = docText.substr(0, blockBegin).lastIndexOf("\n");
+  if (indentBegin < 0)
+    return;
+  var indentStr = docText.substring(indentBegin+1, blockBegin);
 
   DEBUG_LOG("enigmailMsgComposeOverlay.js: enigDecryptQuote: indentStr='"+indentStr+"'\n");
 
