@@ -13,7 +13,7 @@
  *
  * The Initial Developer of this code is Patrick Brunschwig.
  * Portions created by Patrick Brunschwig <patrick.brunschwig@gmx.net>
- * are Copyright (C) 2004 Patrick Brunschwig.
+ * are Copyright (C) 2004-2005 Patrick Brunschwig.
  * All Rights Reserved.
  *
  * Contributor(s):
@@ -130,14 +130,28 @@ function onLoad () {
     progressMeter: document.getElementById("dialog.progress"),
     httpInProgress: false
   };
-
-  switch (window.enigRequest.requestType) {
-  case ENIG_CONN_TYPE_HTTP:
-    enigNewHttpRequest(nsIEnigmail.SEARCH_KEY, enigScanKeys);
-    break;
-  case ENIG_CONN_TYPE_GPGKEYS:
-    enigNewGpgKeysRequest(nsIEnigmail.SEARCH_KEY, enigScanKeys);
-    break;
+  
+  window.enigRequest.progressMeter.mode="undetermined";
+  
+  if (window.arguments[INPUT].searchList.length == 1 &&
+      window.arguments[INPUT].searchList[0].search(/^0x[A-Fa-f0-9]{8,16}$/) == 0) {
+      // shrink dialog and start download if just one key ID provided
+      
+      window.enigRequest.dlKeyList = [ window.arguments[INPUT].searchList ];
+      document.getElementById("keySelGroup").setAttribute("collapsed", "true");
+      window.sizeToContent();
+      window.resizeBy(0, -320);
+      window.setTimeout(startDownload, 10);
+  }
+  else {
+    switch (window.enigRequest.requestType) {
+    case ENIG_CONN_TYPE_HTTP:
+      enigNewHttpRequest(nsIEnigmail.SEARCH_KEY, enigScanKeys);
+      break;
+    case ENIG_CONN_TYPE_GPGKEYS:
+      enigNewGpgKeysRequest(nsIEnigmail.SEARCH_KEY, enigScanKeys);
+      break;
+    }
   }
   return true;
 }
@@ -161,13 +175,19 @@ function onAccept () {
     }
     item = item.nextSibling;
   }
+  return startDownload();
+}
 
+
+function startDownload() {
+  DEBUG_LOG("enigmailSearchKey.js: startDownload\n");
   if (window.enigRequest.dlKeyList.length>0) {
     window.enigRequest.progressMeter.value = 0;
-    window.enigRequest.progressMeter.mode = "determined";
+    window.enigRequest.progressMeter.mode = "undetermined";
     document.getElementById("progress.box").removeAttribute("hidden");
     document.getElementById("dialog.accept").setAttribute("disabled", "true");
     window.enigRequest.keyNum = 0;
+    window.enigRequest.errorTxt="";
     switch (window.enigRequest.requestType) {
     case ENIG_CONN_TYPE_HTTP:
       enigNewHttpRequest(nsIEnigmail.DOWNLOAD_KEY, enigImportKeys);
@@ -237,14 +257,23 @@ function enigStatusLoaded (event) {
 }
 
 
-function enigImportKeys (connType, txt) {
+function enigImportKeys (connType, txt, errorTxt) {
   DEBUG_LOG("enigmailSearchKey.js: enigImportKeys\n");
   
   window.enigRequest.keyNum++;
   window.enigRequest.progressMeter.mode = "determined";
   window.enigRequest.progressMeter.value = (100 * window.enigRequest.keyNum / window.enigRequest.dlKeyList.length).toFixed(0);
 
-  if (!enigImportHtmlKeys(txt)) return;
+  if (txt.search(/^\[GNUPG:\] IMPORT_RES/m) < 0) {
+    if (!enigImportHtmlKeys(txt)) return;
+  }
+  else if (errorTxt) {
+    window.enigRequest.errorTxt +=errorTxt+"\n";
+  }
+  
+  if (txt.search(/^\[GNUPG:\] IMPORT_RES/m) >= 0) {
+    window.arguments[RESULT].importedKeys++;
+  }
 
   if (window.enigRequest.dlKeyList.length > window.enigRequest.keyNum) {
     switch (connType) {
@@ -256,6 +285,9 @@ function enigImportKeys (connType, txt) {
     }
     return;
   }
+  else if (window.enigRequest.errorTxt) {
+    EnigLongAlert(window.enigRequest.errorTxt);
+  }
   
   window.enigRequest.httpInProgress=false;
   
@@ -576,33 +608,42 @@ function enigGpgkeysCloseRequest() {
 function enigmailGpgkeysTerminate(terminateArg, ipcRequest) {
    DEBUG_LOG("enigmailSearchkey.js: Terminate: "+ipcRequest+"\n");
 
-   var GpgkeysProcess = ipcRequest.pipeTransport;
+   var gpgkeysRequest = window.enigRequest.gpgkeysRequest;
+   var gpgkeysProcess = gpgkeysRequest.pipeTransport;
    var enigmailSvc = GetEnigmailSvc();
-   if (GpgkeysProcess && !GpgkeysProcess.isAttached) {
-     GpgkeysProcess.terminate();
-     var exitCode = GpgkeysProcess.exitCode();
+   if (gpgkeysProcess && !gpgkeysProcess.isAttached()) {
+     gpgkeysProcess.terminate();
+     var exitCode = gpgkeysProcess.exitCode();
      DEBUG_LOG("enigmailGpgkeysConsole: exitCode = "+exitCode+"\n");
      if (enigmailSvc) {
         exitCode = enigmailSvc.fixExitCode(exitCode, 0);
      }
    }
 
-  var console = window.enigRequest.gpgkeysRequest.stdoutConsole;
+  var console = gpgkeysRequest.stdoutConsole;
 
   try {
     console = console.QueryInterface(Components.interfaces.nsIPipeConsole);
     var txt = null;
+    var errorTxt = null;
 
     if (console && console.hasNewData()) {
-      DEBUG_LOG("enigmailSearchkey.js: enigRefreshConsole(): hasNewData\n");
+      DEBUG_LOG("enigmailSearchkey.js: Terminate(): stdout.hasNewData\n");
       txt = console.getData();
     }
-    
-    ipcRequest.close(true);
+    console = gpgkeysRequest.stderrConsole;
+    console = console.QueryInterface(Components.interfaces.nsIPipeConsole);
+    if (console && console.hasNewData()) {
+      DEBUG_LOG("enigmailSearchkey.js: Terminate(): stderr.hasNewData\n");
+      errorTxt = console.getData();
+    }
+//    gpgkeysProcess.close(true);
     enigGpgkeysCloseRequest();
 
-    if (txt)
-      window.enigRequest.callbackFunction(ENIG_CONN_TYPE_GPGKEYS, txt);
+    if (txt) {
+      window.enigRequest.callbackFunction(ENIG_CONN_TYPE_GPGKEYS, txt, errorTxt);
+    }
+    
   } catch (ex) {}
 }
 
@@ -636,6 +677,7 @@ function enigPopulateList(keyList) {
   }
   
   if (keyList.length == 1) {
+    // activate found item if just one key found
     enigSetActive(treeItem.firstChild.firstChild, 1);
   }
 }
